@@ -212,10 +212,11 @@ def mem_cache(
 	the cache will be stored globally, so that it can be shared accross multiple
 	methods of multiple instances of a class. A `global_name` can be
 	defined to identify the method; otherwise, the method name will be used. '''
+	print('mem_cache(%s)' % global_name)
 	if key is None:
 		key = lambda *args, **kwargs: frozenset(args + tuple(kwargs.items()))
 	if method is None:
-		return lambda method: mem_cache(method, key=key, maxsize=maxsize)
+		return lambda method: mem_cache(method, key=key, maxsize=maxsize, is_global=is_global, global_name=global_name)
 	if is_global:
 		if global_name is None: global_name = method.__name__
 		cache, cache_usage = _mem_cache_global.get(global_name, ({}, []))
